Class: Aws::TaxSettings::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::TaxSettings::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-taxsettings/client.rb,
sig/client.rbs
Overview
An API client for TaxSettings. To construct a client, you need to configure a :region and :credentials.
client = Aws::TaxSettings::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchDeleteTaxRegistrationResponseSuccess, _BatchGetTaxExemptionsResponseSuccess, _BatchPutTaxRegistrationResponseSuccess, _DeleteSupplementalTaxRegistrationResponseSuccess, _DeleteTaxRegistrationResponseSuccess, _GetTaxExemptionTypesResponseSuccess, _GetTaxInheritanceResponseSuccess, _GetTaxRegistrationDocumentResponseSuccess, _GetTaxRegistrationResponseSuccess, _ListSupplementalTaxRegistrationsResponseSuccess, _ListTaxExemptionsResponseSuccess, _ListTaxRegistrationsResponseSuccess, _PutSupplementalTaxRegistrationResponseSuccess, _PutTaxExemptionResponseSuccess, _PutTaxInheritanceResponseSuccess, _PutTaxRegistrationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_delete_tax_registration(params = {}) ⇒ Types::BatchDeleteTaxRegistrationResponse
Deletes tax registration for multiple accounts in batch.
-
#batch_get_tax_exemptions(params = {}) ⇒ Types::BatchGetTaxExemptionsResponse
Get the active tax exemptions for a given list of accounts.
-
#batch_put_tax_registration(params = {}) ⇒ Types::BatchPutTaxRegistrationResponse
Adds or updates tax registration for multiple accounts in batch.
-
#delete_supplemental_tax_registration(params = {}) ⇒ Struct
Deletes a supplemental tax registration for a single account.
-
#delete_tax_registration(params = {}) ⇒ Struct
Deletes tax registration for a single account.
-
#get_tax_exemption_types(params = {}) ⇒ Types::GetTaxExemptionTypesResponse
Get supported tax exemption types.
-
#get_tax_inheritance(params = {}) ⇒ Types::GetTaxInheritanceResponse
The get account tax inheritance status.
-
#get_tax_registration(params = {}) ⇒ Types::GetTaxRegistrationResponse
Retrieves tax registration for a single account.
-
#get_tax_registration_document(params = {}) ⇒ Types::GetTaxRegistrationDocumentResponse
Downloads your tax documents to the Amazon S3 bucket that you specify in your request.
-
#list_supplemental_tax_registrations(params = {}) ⇒ Types::ListSupplementalTaxRegistrationsResponse
Retrieves supplemental tax registrations for a single account.
-
#list_tax_exemptions(params = {}) ⇒ Types::ListTaxExemptionsResponse
Retrieves the tax exemption of accounts listed in a consolidated billing family.
-
#list_tax_registrations(params = {}) ⇒ Types::ListTaxRegistrationsResponse
Retrieves the tax registration of accounts listed in a consolidated billing family.
-
#put_supplemental_tax_registration(params = {}) ⇒ Types::PutSupplementalTaxRegistrationResponse
Stores supplemental tax registration for a single account.
-
#put_tax_exemption(params = {}) ⇒ Types::PutTaxExemptionResponse
Adds the tax exemption for a single account or all accounts listed in a consolidated billing family.
-
#put_tax_inheritance(params = {}) ⇒ Struct
The updated tax inheritance status.
-
#put_tax_registration(params = {}) ⇒ Types::PutTaxRegistrationResponse
Adds or updates tax registration for a single account.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1978 1979 1980 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1978 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1981 1982 1983 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1981 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_delete_tax_registration(params = {}) ⇒ Types::BatchDeleteTaxRegistrationResponse
Deletes tax registration for multiple accounts in batch. This can be used to delete tax registrations for up to five accounts in one batch.
86 |
# File 'sig/client.rbs', line 86
def batch_delete_tax_registration: (
|
#batch_get_tax_exemptions(params = {}) ⇒ Types::BatchGetTaxExemptionsResponse
Get the active tax exemptions for a given list of accounts. The IAM
action is tax:GetExemptions.
97 |
# File 'sig/client.rbs', line 97
def batch_get_tax_exemptions: (
|
#batch_put_tax_registration(params = {}) ⇒ Types::BatchPutTaxRegistrationResponse
Adds or updates tax registration for multiple accounts in batch. This can be used to add or update tax registrations for up to five accounts in one batch. You can't set a TRN if there's a pending TRN. You'll need to delete the pending TRN first.
To call this API operation for specific countries, see the following country-specific requirements.
Bangladesh
- You must specify the tax registration certificate document in the
taxRegistrationDocumentsfield of theVerificationDetailsobject.
^
Brazil
-
You must complete the tax registration process in the Payment preferences page in the Billing and Cost Management console. After your TRN and billing address are verified, you can call this API operation.
-
For Amazon Web Services accounts created through Organizations, you can call this API operation when you don't have a billing address.
Georgia
- The valid
personTypevalues arePhysical PersonandBusiness.
^
Indonesia
-
PutTaxRegistration: The use of this operation to submit tax information is subject to the Amazon Web Services service terms. By submitting, you’re providing consent for Amazon Web Services to validate NIK, NPWP, and NITKU data, provided by you with the Directorate General of Taxes of Indonesia in accordance with the Minister of Finance Regulation (PMK) Number 112/PMK.03/2022. -
BatchPutTaxRegistration: The use of this operation to submit tax information is subject to the Amazon Web Services service terms. By submitting, you’re providing consent for Amazon Web Services to validate NIK, NPWP, and NITKU data, provided by you with the Directorate General of Taxes of Indonesia in accordance with the Minister of Finance Regulation (PMK) Number 112/PMK.03/2022, through our third-party partner PT Achilles Advanced Management (OnlinePajak). -
You must specify the
taxRegistrationNumberTypein theindonesiaAdditionalInfofield of theadditionalTaxInformationobject. -
If you specify
decisionNumber, you must specify theppnExceptionDesignationCodein theindonesiaAdditionalInfofield of theadditionalTaxInformationobject. If thetaxRegistrationNumberTypeis set to NPWP or NITKU, valid values forppnExceptionDesignationCodeare either01,02,03,07, or08.For other
taxRegistrationNumberTypevalues,ppnExceptionDesignationCodemust be either01,07, or08. -
If
ppnExceptionDesignationCodeis07or08, you must specify thedecisionNumberin theindonesiaAdditionalInfofield of theadditionalTaxInformationobject.
Kenya
-
You must specify the
personTypein thekenyaAdditionalInfofield of theadditionalTaxInformationobject. -
If the
personTypeisPhysical Person, you must specify the tax registration certificate document in thetaxRegistrationDocumentsfield of theVerificationDetailsobject.
Malaysia
-
The sector valid values are
BusinessandIndividual. -
RegistrationTypevalid values areNRICfor individual, and TIN and sales and service tax (SST) for Business. -
For individual, you can specify the
taxInformationNumberinMalaysiaAdditionalInfowith NRIC type, and a validMyKador NRIC number. -
For business, you must specify a
businessRegistrationNumberinMalaysiaAdditionalInfowith a TIN type and tax identification number. -
For business resellers, you must specify a
businessRegistrationNumberandtaxInformationNumberinMalaysiaAdditionalInfowith a sales and service tax (SST) type and a valid SST number. -
For business resellers with service codes, you must specify
businessRegistrationNumber,taxInformationNumber, and distinctserviceTaxCodesinMalaysiaAdditionalInfowith a SST type and valid sales and service tax (SST) number. By using this API operation, Amazon Web Services registers your self-declaration that you’re an authorized business reseller registered with the Royal Malaysia Customs Department (RMCD), and have a valid SST number. -
Amazon Web Services reserves the right to seek additional information and/or take other actions to support your self-declaration as appropriate.
-
Amazon Web Services is currently registered under the following service tax codes. You must include at least one of the service tax codes in the service tax code strings to declare yourself as an authorized registered business reseller.
Taxable service and service tax codes:
Consultancy - 9907061674
Training or coaching service - 9907071685
IT service - 9907101676
Digital services and electronic medium - 9907121690
Mexico
-
You must provide a Constancia de Situación fiscal (CSF) document in the verificationDetails field.
-
You do not need to provide address and legal name. These will be populated based on your tax registration number.
Nepal
- The sector valid values are
BusinessandIndividual.
^
Saudi Arabia
- For
address, you must specifyaddressLine3.
^
South Korea
-
You must specify the
certifiedEmailIdandlegalNamein theTaxRegistrationEntryobject. Use Korean characters forlegalName. -
You must specify the
businessRepresentativeName,itemOfBusiness, andlineOfBusinessin thesouthKoreaAdditionalInfofield of theadditionalTaxInformationobject. Use Korean characters for these fields. -
You must specify the tax registration certificate document in the
taxRegistrationDocumentsfield of theVerificationDetailsobject. -
For the
addressobject, use Korean characters foraddressLine1,addressLine2city,postalCode, andstateOrRegion.
Spain
-
You must specify the
registrationTypein thespainAdditionalInfofield of theadditionalTaxInformationobject. -
If the
registrationTypeisLocal, you must specify the tax registration certificate document in thetaxRegistrationDocumentsfield of theVerificationDetailsobject.
Turkey
-
You must specify the
sectorin thetaxRegistrationEntryobject. -
If your
sectorisBusiness,Individual, orGovernment: -
Specify the
taxOffice. If yoursectorisIndividual, don't enter this value. -
(Optional) Specify the
kepEmailId. If yoursectorisIndividual, don't enter this value. -
Note: In the Tax Settings page of the Billing console,
Governmentappears as Public institutions -
If your
sectorisBusinessand you're subject to KDV tax, you must specify your industry in theindustriesfield. -
For
address, you must specifydistrictOrCounty.
Ukraine
- The sector valid values are
BusinessandIndividual.
^
Philippines
- You can optionally specify the
isVatRegisteredin thephilippinesAdditionalInfofield of theadditionalTaxInformationobject to indicate your VAT registration status with the Bureau of Internal Revenue (BIR).
^
Belgium
- You can optionally specify the
peppolIdin thebelgiumAdditionalInfofield of theadditionalTaxInformationobject.
^
Chile
- You can optionally specify the
documentTypeandbusinessActivityin thechileAdditionalInfofield of theadditionalTaxInformationobject.
^
France
- You must specify the
sirenNumberin thefranceAdditionalInfofield of theadditionalTaxInformationobject.
^
Poland
- You can optionally specify the
taxRegistrationNumberTypein thepolandAdditionalInfofield of theadditionalTaxInformationobject. Valid values areEUTaxRegistrationNumber,LocalTaxRegistrationNumber, orLocalRegistrationNumber.
^
108 |
# File 'sig/client.rbs', line 108
def batch_put_tax_registration: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1951 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::TaxSettings') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-taxsettings' context[:gem_version] = '1.43.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_supplemental_tax_registration(params = {}) ⇒ Struct
Deletes a supplemental tax registration for a single account.
118 |
# File 'sig/client.rbs', line 118
def delete_supplemental_tax_registration: (
|
#delete_tax_registration(params = {}) ⇒ Struct
Deletes tax registration for a single account.
127 |
# File 'sig/client.rbs', line 127
def delete_tax_registration: (
|
#get_tax_exemption_types(params = {}) ⇒ Types::GetTaxExemptionTypesResponse
Get supported tax exemption types. The IAM action is
tax:GetExemptions.
137 |
# File 'sig/client.rbs', line 137
def get_tax_exemption_types: (
|
#get_tax_inheritance(params = {}) ⇒ Types::GetTaxInheritanceResponse
The get account tax inheritance status.
146 |
# File 'sig/client.rbs', line 146
def get_tax_inheritance: (
|
#get_tax_registration(params = {}) ⇒ Types::GetTaxRegistrationResponse
Retrieves tax registration for a single account.
155 |
# File 'sig/client.rbs', line 155
def get_tax_registration: (
|
#get_tax_registration_document(params = {}) ⇒ Types::GetTaxRegistrationDocumentResponse
Downloads your tax documents to the Amazon S3 bucket that you specify in your request.
166 |
# File 'sig/client.rbs', line 166
def get_tax_registration_document: (
|
#list_supplemental_tax_registrations(params = {}) ⇒ Types::ListSupplementalTaxRegistrationsResponse
Retrieves supplemental tax registrations for a single account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
184 |
# File 'sig/client.rbs', line 184
def list_supplemental_tax_registrations: (
|
#list_tax_exemptions(params = {}) ⇒ Types::ListTaxExemptionsResponse
Retrieves the tax exemption of accounts listed in a consolidated
billing family. The IAM action is tax:GetExemptions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
196 |
# File 'sig/client.rbs', line 196
def list_tax_exemptions: (
|
#list_tax_registrations(params = {}) ⇒ Types::ListTaxRegistrationsResponse
Retrieves the tax registration of accounts listed in a consolidated billing family. This can be used to retrieve up to 100 accounts' tax registrations in one call (default 50).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
208 |
# File 'sig/client.rbs', line 208
def list_tax_registrations: (
|
#put_supplemental_tax_registration(params = {}) ⇒ Types::PutSupplementalTaxRegistrationResponse
Stores supplemental tax registration for a single account.
220 |
# File 'sig/client.rbs', line 220
def put_supplemental_tax_registration: (
|
#put_tax_exemption(params = {}) ⇒ Types::PutTaxExemptionResponse
Adds the tax exemption for a single account or all accounts listed in
a consolidated billing family. The IAM action is
tax:UpdateExemptions.
235 |
# File 'sig/client.rbs', line 235
def put_tax_exemption: (
|
#put_tax_inheritance(params = {}) ⇒ Struct
The updated tax inheritance status.
253 |
# File 'sig/client.rbs', line 253
def put_tax_inheritance: (
|
#put_tax_registration(params = {}) ⇒ Types::PutTaxRegistrationResponse
Adds or updates tax registration for a single account. You can't set a TRN if there's a pending TRN. You'll need to delete the pending TRN first.
To call this API operation for specific countries, see the following country-specific requirements.
Bangladesh
- You must specify the tax registration certificate document in the
taxRegistrationDocumentsfield of theVerificationDetailsobject.
^
Brazil
-
You must complete the tax registration process in the Payment preferences page in the Billing and Cost Management console. After your TRN and billing address are verified, you can call this API operation.
-
For Amazon Web Services accounts created through Organizations, you can call this API operation when you don't have a billing address.
Georgia
- The valid
personTypevalues arePhysical PersonandBusiness.
^
Indonesia
-
PutTaxRegistration: The use of this operation to submit tax information is subject to the Amazon Web Services service terms. By submitting, you’re providing consent for Amazon Web Services to validate NIK, NPWP, and NITKU data, provided by you with the Directorate General of Taxes of Indonesia in accordance with the Minister of Finance Regulation (PMK) Number 112/PMK.03/2022. -
BatchPutTaxRegistration: The use of this operation to submit tax information is subject to the Amazon Web Services service terms. By submitting, you’re providing consent for Amazon Web Services to validate NIK, NPWP, and NITKU data, provided by you with the Directorate General of Taxes of Indonesia in accordance with the Minister of Finance Regulation (PMK) Number 112/PMK.03/2022, through our third-party partner PT Achilles Advanced Management (OnlinePajak). -
You must specify the
taxRegistrationNumberTypein theindonesiaAdditionalInfofield of theadditionalTaxInformationobject. -
If you specify
decisionNumber, you must specify theppnExceptionDesignationCodein theindonesiaAdditionalInfofield of theadditionalTaxInformationobject. If thetaxRegistrationNumberTypeis set to NPWP or NITKU, valid values forppnExceptionDesignationCodeare either01,02,03,07, or08.For other
taxRegistrationNumberTypevalues,ppnExceptionDesignationCodemust be either01,07, or08. -
If
ppnExceptionDesignationCodeis07or08, you must specify thedecisionNumberin theindonesiaAdditionalInfofield of theadditionalTaxInformationobject.
Kenya
-
You must specify the
personTypein thekenyaAdditionalInfofield of theadditionalTaxInformationobject. -
If the
personTypeisPhysical Person, you must specify the tax registration certificate document in thetaxRegistrationDocumentsfield of theVerificationDetailsobject.
Malaysia
-
The sector valid values are
BusinessandIndividual. -
RegistrationTypevalid values areNRICfor individual, and TIN and sales and service tax (SST) for Business. -
For individual, you can specify the
taxInformationNumberinMalaysiaAdditionalInfowith NRIC type, and a validMyKador NRIC number. -
For business, you must specify a
businessRegistrationNumberinMalaysiaAdditionalInfowith a TIN type and tax identification number. -
For business resellers, you must specify a
businessRegistrationNumberandtaxInformationNumberinMalaysiaAdditionalInfowith a sales and service tax (SST) type and a valid SST number. -
For business resellers with service codes, you must specify
businessRegistrationNumber,taxInformationNumber, and distinctserviceTaxCodesinMalaysiaAdditionalInfowith a SST type and valid sales and service tax (SST) number. By using this API operation, Amazon Web Services registers your self-declaration that you’re an authorized business reseller registered with the Royal Malaysia Customs Department (RMCD), and have a valid SST number. -
Amazon Web Services reserves the right to seek additional information and/or take other actions to support your self-declaration as appropriate.
-
Amazon Web Services is currently registered under the following service tax codes. You must include at least one of the service tax codes in the service tax code strings to declare yourself as an authorized registered business reseller.
Taxable service and service tax codes:
Consultancy - 9907061674
Training or coaching service - 9907071685
IT service - 9907101676
Digital services and electronic medium - 9907121690
Mexico
-
You must provide a Constancia de Situación fiscal (CSF) document in the verificationDetails field.
-
You do not need to provide address and legal name. These will be populated based on your tax registration number.
Nepal
- The sector valid values are
BusinessandIndividual.
^
Saudi Arabia
- For
address, you must specifyaddressLine3.
^
South Korea
-
You must specify the
certifiedEmailIdandlegalNamein theTaxRegistrationEntryobject. Use Korean characters forlegalName. -
You must specify the
businessRepresentativeName,itemOfBusiness, andlineOfBusinessin thesouthKoreaAdditionalInfofield of theadditionalTaxInformationobject. Use Korean characters for these fields. -
You must specify the tax registration certificate document in the
taxRegistrationDocumentsfield of theVerificationDetailsobject. -
For the
addressobject, use Korean characters foraddressLine1,addressLine2city,postalCode, andstateOrRegion.
Spain
-
You must specify the
registrationTypein thespainAdditionalInfofield of theadditionalTaxInformationobject. -
If the
registrationTypeisLocal, you must specify the tax registration certificate document in thetaxRegistrationDocumentsfield of theVerificationDetailsobject.
Turkey
-
You must specify the
sectorin thetaxRegistrationEntryobject. -
If your
sectorisBusiness,Individual, orGovernment: -
Specify the
taxOffice. If yoursectorisIndividual, don't enter this value. -
(Optional) Specify the
kepEmailId. If yoursectorisIndividual, don't enter this value. -
Note: In the Tax Settings page of the Billing console,
Governmentappears as Public institutions -
If your
sectorisBusinessand you're subject to KDV tax, you must specify your industry in theindustriesfield. -
For
address, you must specifydistrictOrCounty.
Ukraine
- The sector valid values are
BusinessandIndividual.
^
Philippines
- You can optionally specify the
isVatRegisteredin thephilippinesAdditionalInfofield of theadditionalTaxInformationobject to indicate your VAT registration status with the Bureau of Internal Revenue (BIR).
^
Belgium
- You can optionally specify the
peppolIdin thebelgiumAdditionalInfofield of theadditionalTaxInformationobject.
^
Chile
- You can optionally specify the
documentTypeandbusinessActivityin thechileAdditionalInfofield of theadditionalTaxInformationobject.
^
France
- You must specify the
sirenNumberin thefranceAdditionalInfofield of theadditionalTaxInformationobject.
^
Poland
- You can optionally specify the
taxRegistrationNumberTypein thepolandAdditionalInfofield of theadditionalTaxInformationobject. Valid values areEUTaxRegistrationNumber,LocalTaxRegistrationNumber, orLocalRegistrationNumber.
^
263 |
# File 'sig/client.rbs', line 263
def put_tax_registration: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1971 1972 1973 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1971 def waiter_names [] end |