Class: Aws::TaxSettings::Types::IndonesiaAdditionalInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::TaxSettings::Types::IndonesiaAdditionalInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-taxsettings/types.rb
Overview
Additional tax information associated with your TRN in Indonesia.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#decision_number ⇒ String
VAT-exempt customers have a Directorate General of Taxation (DGT) exemption letter or certificate (Surat Keterangan Bebas) decision number.
-
#ppn_exception_designation_code ⇒ String
Exception code if you are designated by Directorate General of Taxation (DGT) as a VAT collector, non-collected VAT, or VAT-exempt customer.
-
#tax_registration_number_type ⇒ String
The tax registration number type.
Instance Attribute Details
#decision_number ⇒ String
VAT-exempt customers have a Directorate General of Taxation (DGT) exemption letter or certificate (Surat Keterangan Bebas) decision number. Non-collected VAT have a DGT letter or certificate (Surat Keterangan Tidak Dipungut).
1048 1049 1050 1051 1052 1053 1054 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1048 class IndonesiaAdditionalInfo < Struct.new( :tax_registration_number_type, :ppn_exception_designation_code, :decision_number) SENSITIVE = [] include Aws::Structure end |
#ppn_exception_designation_code ⇒ String
Exception code if you are designated by Directorate General of Taxation (DGT) as a VAT collector, non-collected VAT, or VAT-exempt customer.
1048 1049 1050 1051 1052 1053 1054 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1048 class IndonesiaAdditionalInfo < Struct.new( :tax_registration_number_type, :ppn_exception_designation_code, :decision_number) SENSITIVE = [] include Aws::Structure end |
#tax_registration_number_type ⇒ String
The tax registration number type.
1048 1049 1050 1051 1052 1053 1054 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1048 class IndonesiaAdditionalInfo < Struct.new( :tax_registration_number_type, :ppn_exception_designation_code, :decision_number) SENSITIVE = [] include Aws::Structure end |