Class: Aws::TaxSettings::Types::IsraelAdditionalInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::TaxSettings::Types::IsraelAdditionalInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-taxsettings/types.rb
Overview
Additional tax information associated with your TRN in Israel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#customer_type ⇒ String
Customer type for your TRN in Israel.
-
#dealer_type ⇒ String
Dealer type for your TRN in Israel.
Instance Attribute Details
#customer_type ⇒ String
Customer type for your TRN in Israel. The value can be ‘Business` or `Individual`. Use `Business`for entities such as not-for-profit and financial institutions.
1092 1093 1094 1095 1096 1097 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1092 class IsraelAdditionalInfo < Struct.new( :dealer_type, :customer_type) SENSITIVE = [] include Aws::Structure end |
#dealer_type ⇒ String
Dealer type for your TRN in Israel. If you’re not a local authorized dealer with an Israeli VAT ID, specify your tax identification number so that Amazon Web Services can send you a compliant tax invoice.
1092 1093 1094 1095 1096 1097 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1092 class IsraelAdditionalInfo < Struct.new( :dealer_type, :customer_type) SENSITIVE = [] include Aws::Structure end |