Class: Aws::TaxSettings::Types::ItalyAdditionalInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::TaxSettings::Types::ItalyAdditionalInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-taxsettings/types.rb
Overview
Additional tax information associated with your TRN in Italy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cig_number ⇒ String
The tender procedure identification code.
-
#cup_number ⇒ String
Additional tax information to specify for a TRN in Italy.
-
#customer_type ⇒ String
The customer type for tax registration in Italy.
-
#sdi_account_id ⇒ String
Additional tax information to specify for a TRN in Italy.
-
#tax_code ⇒ String
List of service tax codes for your TRN in Italy.
Instance Attribute Details
#cig_number ⇒ String
The tender procedure identification code.
1130 1131 1132 1133 1134 1135 1136 1137 1138 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1130 class ItalyAdditionalInfo < Struct.new( :sdi_account_id, :cig_number, :cup_number, :tax_code, :customer_type) SENSITIVE = [] include Aws::Structure end |
#cup_number ⇒ String
Additional tax information to specify for a TRN in Italy. This is managed by the Interministerial Committee for Economic Planning (CIPE) which characterizes every public investment project (Individual Project Code).
1130 1131 1132 1133 1134 1135 1136 1137 1138 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1130 class ItalyAdditionalInfo < Struct.new( :sdi_account_id, :cig_number, :cup_number, :tax_code, :customer_type) SENSITIVE = [] include Aws::Structure end |
#customer_type ⇒ String
The customer type for tax registration in Italy. Valid values are ‘Business` or `Individual`.
1130 1131 1132 1133 1134 1135 1136 1137 1138 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1130 class ItalyAdditionalInfo < Struct.new( :sdi_account_id, :cig_number, :cup_number, :tax_code, :customer_type) SENSITIVE = [] include Aws::Structure end |
#sdi_account_id ⇒ String
Additional tax information to specify for a TRN in Italy. Use CodiceDestinatario to receive your invoices via web service (API) or FTP.
1130 1131 1132 1133 1134 1135 1136 1137 1138 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1130 class ItalyAdditionalInfo < Struct.new( :sdi_account_id, :cig_number, :cup_number, :tax_code, :customer_type) SENSITIVE = [] include Aws::Structure end |
#tax_code ⇒ String
List of service tax codes for your TRN in Italy. You can use your customer tax code as part of a VAT Group.
1130 1131 1132 1133 1134 1135 1136 1137 1138 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1130 class ItalyAdditionalInfo < Struct.new( :sdi_account_id, :cig_number, :cup_number, :tax_code, :customer_type) SENSITIVE = [] include Aws::Structure end |