Class: Aws::TaxSettings::Types::PhilippinesAdditionalInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::TaxSettings::Types::PhilippinesAdditionalInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-taxsettings/types.rb
Overview
Additional tax information associated with your TRN in the Philippines.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_vat_registered ⇒ Boolean
Indicates whether the account is VAT-registered with the Philippines Bureau of Internal Revenue (BIR).
Instance Attribute Details
#is_vat_registered ⇒ Boolean
Indicates whether the account is VAT-registered with the Philippines Bureau of Internal Revenue (BIR).
1346 1347 1348 1349 1350 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1346 class PhilippinesAdditionalInfo < Struct.new( :is_vat_registered) SENSITIVE = [] include Aws::Structure end |