Class: Aws::TaxSettings::Types::SouthKoreaAdditionalInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-taxsettings/types.rb

Overview

Additional tax information associated with your TRN in South Korea.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#business_representative_nameString

The business legal name based on the most recently uploaded tax registration certificate.

Returns:

  • (String)


1588
1589
1590
1591
1592
1593
1594
# File 'lib/aws-sdk-taxsettings/types.rb', line 1588

class SouthKoreaAdditionalInfo < Struct.new(
  :business_representative_name,
  :line_of_business,
  :item_of_business)
  SENSITIVE = []
  include Aws::Structure
end

#item_of_businessString

Item of business based on the most recently uploaded tax registration certificate.

Returns:

  • (String)


1588
1589
1590
1591
1592
1593
1594
# File 'lib/aws-sdk-taxsettings/types.rb', line 1588

class SouthKoreaAdditionalInfo < Struct.new(
  :business_representative_name,
  :line_of_business,
  :item_of_business)
  SENSITIVE = []
  include Aws::Structure
end

#line_of_businessString

Line of business based on the most recently uploaded tax registration certificate.

Returns:

  • (String)


1588
1589
1590
1591
1592
1593
1594
# File 'lib/aws-sdk-taxsettings/types.rb', line 1588

class SouthKoreaAdditionalInfo < Struct.new(
  :business_representative_name,
  :line_of_business,
  :item_of_business)
  SENSITIVE = []
  include Aws::Structure
end