Class: Aws::TaxSettings::Types::TaxExemptionDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-taxsettings/types.rb

Overview

The tax exemption details.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#heritage_obtained_detailsBoolean

The indicator if the tax exemption is inherited from the consolidated billing family management account.

Returns:

  • (Boolean)


1767
1768
1769
1770
1771
1772
1773
1774
# File 'lib/aws-sdk-taxsettings/types.rb', line 1767

class TaxExemptionDetails < Struct.new(
  :tax_exemptions,
  :heritage_obtained_details,
  :heritage_obtained_parent_entity,
  :heritage_obtained_reason)
  SENSITIVE = []
  include Aws::Structure
end

#heritage_obtained_parent_entityString

The consolidated billing family management account the tax exemption inherited from.

Returns:

  • (String)


1767
1768
1769
1770
1771
1772
1773
1774
# File 'lib/aws-sdk-taxsettings/types.rb', line 1767

class TaxExemptionDetails < Struct.new(
  :tax_exemptions,
  :heritage_obtained_details,
  :heritage_obtained_parent_entity,
  :heritage_obtained_reason)
  SENSITIVE = []
  include Aws::Structure
end

#heritage_obtained_reasonString

The reason of the heritage inheritance.

Returns:

  • (String)


1767
1768
1769
1770
1771
1772
1773
1774
# File 'lib/aws-sdk-taxsettings/types.rb', line 1767

class TaxExemptionDetails < Struct.new(
  :tax_exemptions,
  :heritage_obtained_details,
  :heritage_obtained_parent_entity,
  :heritage_obtained_reason)
  SENSITIVE = []
  include Aws::Structure
end

#tax_exemptionsArray<Types::TaxExemption>

Tax exemptions.

Returns:



1767
1768
1769
1770
1771
1772
1773
1774
# File 'lib/aws-sdk-taxsettings/types.rb', line 1767

class TaxExemptionDetails < Struct.new(
  :tax_exemptions,
  :heritage_obtained_details,
  :heritage_obtained_parent_entity,
  :heritage_obtained_reason)
  SENSITIVE = []
  include Aws::Structure
end