Class: Aws::TaxSettings::Types::TaxInheritanceDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::TaxSettings::Types::TaxInheritanceDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-taxsettings/types.rb
Overview
Tax inheritance information associated with the account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inheritance_obtained_reason ⇒ String
Tax inheritance reason information associated with the account.
-
#parent_entity_id ⇒ String
Tax inheritance parent account information associated with the account.
Instance Attribute Details
#inheritance_obtained_reason ⇒ String
Tax inheritance reason information associated with the account.
1813 1814 1815 1816 1817 1818 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1813 class TaxInheritanceDetails < Struct.new( :parent_entity_id, :inheritance_obtained_reason) SENSITIVE = [] include Aws::Structure end |
#parent_entity_id ⇒ String
Tax inheritance parent account information associated with the account.
1813 1814 1815 1816 1817 1818 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1813 class TaxInheritanceDetails < Struct.new( :parent_entity_id, :inheritance_obtained_reason) SENSITIVE = [] include Aws::Structure end |