Class: Aws::TaxSettings::Types::TaxRegistrationWithJurisdiction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-taxsettings/types.rb

Overview

Your TRN information with jurisdiction details. This doesn’t contain the full legal address associated with the TRN information.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_tax_informationTypes::AdditionalInfoResponse

Additional tax information associated with your TRN.



2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045

class TaxRegistrationWithJurisdiction < Struct.new(
  :registration_id,
  :registration_type,
  :legal_name,
  :status,
  :sector,
  :tax_document_metadatas,
  :certified_email_id,
  :additional_tax_information,
  :jurisdiction)
  SENSITIVE = []
  include Aws::Structure
end

#certified_email_idString

The email address to receive VAT invoices.

Returns:

  • (String)


2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045

class TaxRegistrationWithJurisdiction < Struct.new(
  :registration_id,
  :registration_type,
  :legal_name,
  :status,
  :sector,
  :tax_document_metadatas,
  :certified_email_id,
  :additional_tax_information,
  :jurisdiction)
  SENSITIVE = []
  include Aws::Structure
end

#jurisdictionTypes::Jurisdiction

The jurisdiction associated with your TRN information.

Returns:



2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045

class TaxRegistrationWithJurisdiction < Struct.new(
  :registration_id,
  :registration_type,
  :legal_name,
  :status,
  :sector,
  :tax_document_metadatas,
  :certified_email_id,
  :additional_tax_information,
  :jurisdiction)
  SENSITIVE = []
  include Aws::Structure
end

The legal name associated with your TRN information.

Returns:

  • (String)


2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045

class TaxRegistrationWithJurisdiction < Struct.new(
  :registration_id,
  :registration_type,
  :legal_name,
  :status,
  :sector,
  :tax_document_metadatas,
  :certified_email_id,
  :additional_tax_information,
  :jurisdiction)
  SENSITIVE = []
  include Aws::Structure
end

#registration_idString

Your tax registration unique identifier.

Returns:

  • (String)


2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045

class TaxRegistrationWithJurisdiction < Struct.new(
  :registration_id,
  :registration_type,
  :legal_name,
  :status,
  :sector,
  :tax_document_metadatas,
  :certified_email_id,
  :additional_tax_information,
  :jurisdiction)
  SENSITIVE = []
  include Aws::Structure
end

#registration_typeString

The type of your tax registration. This can be either ‘VAT` or `GST`.

Returns:

  • (String)


2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045

class TaxRegistrationWithJurisdiction < Struct.new(
  :registration_id,
  :registration_type,
  :legal_name,
  :status,
  :sector,
  :tax_document_metadatas,
  :certified_email_id,
  :additional_tax_information,
  :jurisdiction)
  SENSITIVE = []
  include Aws::Structure
end

#sectorString

The industry that describes your business. For business-to-business (B2B) customers, specify Business. For business-to-consumer (B2C) customers, specify Individual. For business-to-government (B2G), specify Government.Note that certain values may not applicable for the request country. Please refer to country specific information in API document.

Returns:

  • (String)


2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045

class TaxRegistrationWithJurisdiction < Struct.new(
  :registration_id,
  :registration_type,
  :legal_name,
  :status,
  :sector,
  :tax_document_metadatas,
  :certified_email_id,
  :additional_tax_information,
  :jurisdiction)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of your TRN. This can be either ‘Verified`, `Pending`, `Deleted`, or `Rejected`.

Returns:

  • (String)


2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045

class TaxRegistrationWithJurisdiction < Struct.new(
  :registration_id,
  :registration_type,
  :legal_name,
  :status,
  :sector,
  :tax_document_metadatas,
  :certified_email_id,
  :additional_tax_information,
  :jurisdiction)
  SENSITIVE = []
  include Aws::Structure
end

#tax_document_metadatasArray<Types::TaxDocumentMetadata>

The metadata for your tax document.

Returns:



2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045

class TaxRegistrationWithJurisdiction < Struct.new(
  :registration_id,
  :registration_type,
  :legal_name,
  :status,
  :sector,
  :tax_document_metadatas,
  :certified_email_id,
  :additional_tax_information,
  :jurisdiction)
  SENSITIVE = []
  include Aws::Structure
end