Class: Aws::TaxSettings::Types::VietnamAdditionalInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::TaxSettings::Types::VietnamAdditionalInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-taxsettings/types.rb
Overview
Additional tax information to specify for a TRN in Vietnam.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#electronic_transaction_code_number ⇒ String
The electronic transaction code number on the tax return document.
-
#enterprise_identification_number ⇒ String
The enterprise identification number for tax registration.
-
#payment_voucher_number ⇒ String
The payment voucher number on the tax return payment document.
-
#payment_voucher_number_date ⇒ String
The date on the tax return payment document.
Instance Attribute Details
#electronic_transaction_code_number ⇒ String
The electronic transaction code number on the tax return document. This field must be provided for successful API operation.
2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 2219 class VietnamAdditionalInfo < Struct.new( :enterprise_identification_number, :electronic_transaction_code_number, :payment_voucher_number, :payment_voucher_number_date) SENSITIVE = [] include Aws::Structure end |
#enterprise_identification_number ⇒ String
The enterprise identification number for tax registration. This field must be provided for successful API operation.
2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 2219 class VietnamAdditionalInfo < Struct.new( :enterprise_identification_number, :electronic_transaction_code_number, :payment_voucher_number, :payment_voucher_number_date) SENSITIVE = [] include Aws::Structure end |
#payment_voucher_number ⇒ String
The payment voucher number on the tax return payment document. This field must be provided for successful API operation.
2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 2219 class VietnamAdditionalInfo < Struct.new( :enterprise_identification_number, :electronic_transaction_code_number, :payment_voucher_number, :payment_voucher_number_date) SENSITIVE = [] include Aws::Structure end |
#payment_voucher_number_date ⇒ String
The date on the tax return payment document. This field must be provided for successful API operation.
2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 2219 class VietnamAdditionalInfo < Struct.new( :enterprise_identification_number, :electronic_transaction_code_number, :payment_voucher_number, :payment_voucher_number_date) SENSITIVE = [] include Aws::Structure end |