Class: Aws::TaxSettings::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::TaxSettings::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-taxsettings/client.rb
Overview
An API client for TaxSettings. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::TaxSettings::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_delete_tax_registration(params = {}) ⇒ Types::BatchDeleteTaxRegistrationResponse
Deletes tax registration for multiple accounts in batch.
-
#batch_get_tax_exemptions(params = {}) ⇒ Types::BatchGetTaxExemptionsResponse
Get the active tax exemptions for a given list of accounts.
-
#batch_put_tax_registration(params = {}) ⇒ Types::BatchPutTaxRegistrationResponse
Adds or updates tax registration for multiple accounts in batch.
-
#delete_supplemental_tax_registration(params = {}) ⇒ Struct
Deletes a supplemental tax registration for a single account.
-
#delete_tax_registration(params = {}) ⇒ Struct
Deletes tax registration for a single account.
-
#get_tax_exemption_types(params = {}) ⇒ Types::GetTaxExemptionTypesResponse
Get supported tax exemption types.
-
#get_tax_inheritance(params = {}) ⇒ Types::GetTaxInheritanceResponse
The get account tax inheritance status.
-
#get_tax_registration(params = {}) ⇒ Types::GetTaxRegistrationResponse
Retrieves tax registration for a single account.
-
#get_tax_registration_document(params = {}) ⇒ Types::GetTaxRegistrationDocumentResponse
Downloads your tax documents to the Amazon S3 bucket that you specify in your request.
-
#list_supplemental_tax_registrations(params = {}) ⇒ Types::ListSupplementalTaxRegistrationsResponse
Retrieves supplemental tax registrations for a single account.
-
#list_tax_exemptions(params = {}) ⇒ Types::ListTaxExemptionsResponse
Retrieves the tax exemption of accounts listed in a consolidated billing family.
-
#list_tax_registrations(params = {}) ⇒ Types::ListTaxRegistrationsResponse
Retrieves the tax registration of accounts listed in a consolidated billing family.
-
#put_supplemental_tax_registration(params = {}) ⇒ Types::PutSupplementalTaxRegistrationResponse
Stores supplemental tax registration for a single account.
-
#put_tax_exemption(params = {}) ⇒ Types::PutTaxExemptionResponse
Adds the tax exemption for a single account or all accounts listed in a consolidated billing family.
-
#put_tax_inheritance(params = {}) ⇒ Struct
The updated tax inheritance status.
-
#put_tax_registration(params = {}) ⇒ Types::PutTaxRegistrationResponse
Adds or updates tax registration for a single account.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1978 1979 1980 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1978 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1981 1982 1983 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1981 def errors_module Errors end |
Instance Method Details
#batch_delete_tax_registration(params = {}) ⇒ Types::BatchDeleteTaxRegistrationResponse
Deletes tax registration for multiple accounts in batch. This can be used to delete tax registrations for up to five accounts in one batch.
<note markdown=“1”> This API operation can’t be used to delete your tax registration in Brazil. Use the [Payment preferences] page in the Billing and Cost Management console instead.
</note>
[1]: console.aws.amazon.com/billing/home#/paymentpreferences/paymentmethods
514 515 516 517 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 514 def batch_delete_tax_registration(params = {}, = {}) req = build_request(:batch_delete_tax_registration, params) req.send_request() end |
#batch_get_tax_exemptions(params = {}) ⇒ Types::BatchGetTaxExemptionsResponse
Get the active tax exemptions for a given list of accounts. The IAM action is ‘tax:GetExemptions`.
561 562 563 564 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 561 def batch_get_tax_exemptions(params = {}, = {}) req = build_request(:batch_get_tax_exemptions, params) req.send_request() end |
#batch_put_tax_registration(params = {}) ⇒ Types::BatchPutTaxRegistrationResponse
Adds or updates tax registration for multiple accounts in batch. This can be used to add or update tax registrations for up to five accounts in one batch. You can’t set a TRN if there’s a pending TRN. You’ll need to delete the pending TRN first.
To call this API operation for specific countries, see the following country-specific requirements.
Bangladesh
-
You must specify the tax registration certificate document in the ‘taxRegistrationDocuments` field of the `VerificationDetails` object.
^
Brazil
-
You must complete the tax registration process in the [Payment preferences] page in the Billing and Cost Management console. After your TRN and billing address are verified, you can call this API operation.
-
For Amazon Web Services accounts created through Organizations, you can call this API operation when you don’t have a billing address.
Georgia
-
The valid ‘personType` values are `Physical Person` and `Business`.
^
Indonesia
-
‘PutTaxRegistration`: The use of this operation to submit tax information is subject to the [Amazon Web Services service terms]. By submitting, you’re providing consent for Amazon Web Services to validate NIK, NPWP, and NITKU data, provided by you with the Directorate General of Taxes of Indonesia in accordance with the Minister of Finance Regulation (PMK) Number 112/PMK.03/2022.
-
‘BatchPutTaxRegistration`: The use of this operation to submit tax information is subject to the [Amazon Web Services service terms]. By submitting, you’re providing consent for Amazon Web Services to validate NIK, NPWP, and NITKU data, provided by you with the Directorate General of Taxes of Indonesia in accordance with the Minister of Finance Regulation (PMK) Number 112/PMK.03/2022, through our third-party partner PT Achilles Advanced Management (OnlinePajak).
-
You must specify the ‘taxRegistrationNumberType` in the `indonesiaAdditionalInfo` field of the `additionalTaxInformation` object.
-
If you specify ‘decisionNumber`, you must specify the `ppnExceptionDesignationCode` in the `indonesiaAdditionalInfo` field of the `additionalTaxInformation` object. If the `taxRegistrationNumberType` is set to NPWP or NITKU, valid values for `ppnExceptionDesignationCode` are either `01`, `02`, `03`, `07`, or `08`.
For other ‘taxRegistrationNumberType` values, `ppnExceptionDesignationCode` must be either `01`, `07`, or `08`.
-
If ‘ppnExceptionDesignationCode` is `07` or `08`, you must specify the `decisionNumber` in the `indonesiaAdditionalInfo` field of the `additionalTaxInformation` object.
Kenya
-
You must specify the ‘personType` in the `kenyaAdditionalInfo` field of the `additionalTaxInformation` object.
-
If the ‘personType` is `Physical Person`, you must specify the tax registration certificate document in the `taxRegistrationDocuments` field of the `VerificationDetails` object.
Malaysia
-
The sector valid values are ‘Business` and `Individual`.
-
‘RegistrationType` valid values are `NRIC` for individual, and TIN and sales and service tax (SST) for Business.
-
For individual, you can specify the ‘taxInformationNumber` in `MalaysiaAdditionalInfo` with NRIC type, and a valid `MyKad` or NRIC number.
-
For business, you must specify a ‘businessRegistrationNumber` in `MalaysiaAdditionalInfo` with a TIN type and tax identification number.
-
For business resellers, you must specify a ‘businessRegistrationNumber` and `taxInformationNumber` in `MalaysiaAdditionalInfo` with a sales and service tax (SST) type and a valid SST number.
-
For business resellers with service codes, you must specify ‘businessRegistrationNumber`, `taxInformationNumber`, and distinct `serviceTaxCodes` in `MalaysiaAdditionalInfo` with a SST type and valid sales and service tax (SST) number. By using this API operation, Amazon Web Services registers your self-declaration that you’re an authorized business reseller registered with the Royal Malaysia Customs Department (RMCD), and have a valid SST number.
-
Amazon Web Services reserves the right to seek additional information and/or take other actions to support your self-declaration as appropriate.
-
Amazon Web Services is currently registered under the following service tax codes. You must include at least one of the service tax codes in the service tax code strings to declare yourself as an authorized registered business reseller.
Taxable service and service tax codes:
Consultancy - 9907061674
Training or coaching service - 9907071685
IT service - 9907101676
Digital services and electronic medium - 9907121690
Mexico
-
You must provide a Constancia de Situación fiscal (CSF) document in the verificationDetails field.
-
You do not need to provide address and legal name. These will be populated based on your tax registration number.
Nepal
-
The sector valid values are ‘Business` and `Individual`.
^
**Saudi Arabia**
-
For ‘address`, you must specify `addressLine3`.
^
**South Korea**
-
You must specify the ‘certifiedEmailId` and `legalName` in the `TaxRegistrationEntry` object. Use Korean characters for `legalName`.
-
You must specify the ‘businessRepresentativeName`, `itemOfBusiness`, and `lineOfBusiness` in the `southKoreaAdditionalInfo` field of the `additionalTaxInformation` object. Use Korean characters for these fields.
-
You must specify the tax registration certificate document in the ‘taxRegistrationDocuments` field of the `VerificationDetails` object.
-
For the ‘address` object, use Korean characters for `addressLine1`, `addressLine2` `city`, `postalCode`, and `stateOrRegion`.
Spain
-
You must specify the ‘registrationType` in the `spainAdditionalInfo` field of the `additionalTaxInformation` object.
-
If the ‘registrationType` is `Local`, you must specify the tax registration certificate document in the `taxRegistrationDocuments` field of the `VerificationDetails` object.
Turkey
-
You must specify the ‘sector` in the `taxRegistrationEntry` object.
-
If your ‘sector` is `Business`, `Individual`, or `Government`:
-
Specify the ‘taxOffice`. If your `sector` is `Individual`, don’t enter this value.
-
(Optional) Specify the ‘kepEmailId`. If your `sector` is `Individual`, don’t enter this value.
-
Note: In the **Tax Settings** page of the Billing console, ‘Government` appears as **Public institutions**
-
-
If your ‘sector` is `Business` and you’re subject to KDV tax, you must specify your industry in the ‘industries` field.
-
For ‘address`, you must specify `districtOrCounty`.
Ukraine
-
The sector valid values are ‘Business` and `Individual`.
^
Philippines
-
You can optionally specify the ‘isVatRegistered` in the `philippinesAdditionalInfo` field of the `additionalTaxInformation` object to indicate your VAT registration status with the Bureau of Internal Revenue (BIR).
^
Belgium
-
You can optionally specify the ‘peppolId` in the `belgiumAdditionalInfo` field of the `additionalTaxInformation` object.
^
Chile
-
You can optionally specify the ‘documentType` and `businessActivity` in the `chileAdditionalInfo` field of the `additionalTaxInformation` object.
^
France
-
You must specify the ‘sirenNumber` in the `franceAdditionalInfo` field of the `additionalTaxInformation` object.
^
Poland
-
You can optionally specify the ‘taxRegistrationNumberType` in the `polandAdditionalInfo` field of the `additionalTaxInformation` object. Valid values are `EUTaxRegistrationNumber`, `LocalTaxRegistrationNumber`, or `LocalRegistrationNumber`.
^
[1]: console.aws.amazon.com/billing/home#/paymentpreferences/paymentmethods [2]: aws.amazon.com/service-terms/
967 968 969 970 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 967 def batch_put_tax_registration(params = {}, = {}) req = build_request(:batch_put_tax_registration, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1951 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::TaxSettings') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-taxsettings' context[:gem_version] = '1.42.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_supplemental_tax_registration(params = {}) ⇒ Struct
Deletes a supplemental tax registration for a single account.
990 991 992 993 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 990 def delete_supplemental_tax_registration(params = {}, = {}) req = build_request(:delete_supplemental_tax_registration, params) req.send_request() end |
#delete_tax_registration(params = {}) ⇒ Struct
Deletes tax registration for a single account.
<note markdown=“1”> This API operation can’t be used to delete your tax registration in Brazil. Use the [Payment preferences] page in the Billing and Cost Management console instead.
</note>
[1]: console.aws.amazon.com/billing/home#/paymentpreferences/paymentmethods
1024 1025 1026 1027 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1024 def delete_tax_registration(params = {}, = {}) req = build_request(:delete_tax_registration, params) req.send_request() end |
#get_tax_exemption_types(params = {}) ⇒ Types::GetTaxExemptionTypesResponse
Get supported tax exemption types. The IAM action is ‘tax:GetExemptions`.
1049 1050 1051 1052 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1049 def get_tax_exemption_types(params = {}, = {}) req = build_request(:get_tax_exemption_types, params) req.send_request() end |
#get_tax_inheritance(params = {}) ⇒ Types::GetTaxInheritanceResponse
The get account tax inheritance status.
1068 1069 1070 1071 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1068 def get_tax_inheritance(params = {}, = {}) req = build_request(:get_tax_inheritance, params) req.send_request() end |
#get_tax_registration(params = {}) ⇒ Types::GetTaxRegistrationResponse
Retrieves tax registration for a single account.
1165 1166 1167 1168 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1165 def get_tax_registration(params = {}, = {}) req = build_request(:get_tax_registration, params) req.send_request() end |
#get_tax_registration_document(params = {}) ⇒ Types::GetTaxRegistrationDocumentResponse
Downloads your tax documents to the Amazon S3 bucket that you specify in your request.
1207 1208 1209 1210 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1207 def get_tax_registration_document(params = {}, = {}) req = build_request(:get_tax_registration_document, params) req.send_request() end |
#list_supplemental_tax_registrations(params = {}) ⇒ Types::ListSupplementalTaxRegistrationsResponse
Retrieves supplemental tax registrations for a single account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1256 1257 1258 1259 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1256 def list_supplemental_tax_registrations(params = {}, = {}) req = build_request(:list_supplemental_tax_registrations, params) req.send_request() end |
#list_tax_exemptions(params = {}) ⇒ Types::ListTaxExemptionsResponse
Retrieves the tax exemption of accounts listed in a consolidated billing family. The IAM action is ‘tax:GetExemptions`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1308 1309 1310 1311 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1308 def list_tax_exemptions(params = {}, = {}) req = build_request(:list_tax_exemptions, params) req.send_request() end |
#list_tax_registrations(params = {}) ⇒ Types::ListTaxRegistrationsResponse
Retrieves the tax registration of accounts listed in a consolidated billing family. This can be used to retrieve up to 100 accounts’ tax registrations in one call (default 50).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1427 1428 1429 1430 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1427 def list_tax_registrations(params = {}, = {}) req = build_request(:list_tax_registrations, params) req.send_request() end |
#put_supplemental_tax_registration(params = {}) ⇒ Types::PutSupplementalTaxRegistrationResponse
Stores supplemental tax registration for a single account.
1472 1473 1474 1475 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1472 def put_supplemental_tax_registration(params = {}, = {}) req = build_request(:put_supplemental_tax_registration, params) req.send_request() end |
#put_tax_exemption(params = {}) ⇒ Types::PutTaxExemptionResponse
Adds the tax exemption for a single account or all accounts listed in a consolidated billing family. The IAM action is ‘tax:UpdateExemptions`.
1520 1521 1522 1523 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1520 def put_tax_exemption(params = {}, = {}) req = build_request(:put_tax_exemption, params) req.send_request() end |
#put_tax_inheritance(params = {}) ⇒ Struct
The updated tax inheritance status.
1542 1543 1544 1545 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1542 def put_tax_inheritance(params = {}, = {}) req = build_request(:put_tax_inheritance, params) req.send_request() end |
#put_tax_registration(params = {}) ⇒ Types::PutTaxRegistrationResponse
Adds or updates tax registration for a single account. You can’t set a TRN if there’s a pending TRN. You’ll need to delete the pending TRN first.
To call this API operation for specific countries, see the following country-specific requirements.
Bangladesh
-
You must specify the tax registration certificate document in the ‘taxRegistrationDocuments` field of the `VerificationDetails` object.
^
Brazil
-
You must complete the tax registration process in the [Payment preferences] page in the Billing and Cost Management console. After your TRN and billing address are verified, you can call this API operation.
-
For Amazon Web Services accounts created through Organizations, you can call this API operation when you don’t have a billing address.
Georgia
-
The valid ‘personType` values are `Physical Person` and `Business`.
^
Indonesia
-
‘PutTaxRegistration`: The use of this operation to submit tax information is subject to the [Amazon Web Services service terms]. By submitting, you’re providing consent for Amazon Web Services to validate NIK, NPWP, and NITKU data, provided by you with the Directorate General of Taxes of Indonesia in accordance with the Minister of Finance Regulation (PMK) Number 112/PMK.03/2022.
-
‘BatchPutTaxRegistration`: The use of this operation to submit tax information is subject to the [Amazon Web Services service terms]. By submitting, you’re providing consent for Amazon Web Services to validate NIK, NPWP, and NITKU data, provided by you with the Directorate General of Taxes of Indonesia in accordance with the Minister of Finance Regulation (PMK) Number 112/PMK.03/2022, through our third-party partner PT Achilles Advanced Management (OnlinePajak).
-
You must specify the ‘taxRegistrationNumberType` in the `indonesiaAdditionalInfo` field of the `additionalTaxInformation` object.
-
If you specify ‘decisionNumber`, you must specify the `ppnExceptionDesignationCode` in the `indonesiaAdditionalInfo` field of the `additionalTaxInformation` object. If the `taxRegistrationNumberType` is set to NPWP or NITKU, valid values for `ppnExceptionDesignationCode` are either `01`, `02`, `03`, `07`, or `08`.
For other ‘taxRegistrationNumberType` values, `ppnExceptionDesignationCode` must be either `01`, `07`, or `08`.
-
If ‘ppnExceptionDesignationCode` is `07` or `08`, you must specify the `decisionNumber` in the `indonesiaAdditionalInfo` field of the `additionalTaxInformation` object.
Kenya
-
You must specify the ‘personType` in the `kenyaAdditionalInfo` field of the `additionalTaxInformation` object.
-
If the ‘personType` is `Physical Person`, you must specify the tax registration certificate document in the `taxRegistrationDocuments` field of the `VerificationDetails` object.
Malaysia
-
The sector valid values are ‘Business` and `Individual`.
-
‘RegistrationType` valid values are `NRIC` for individual, and TIN and sales and service tax (SST) for Business.
-
For individual, you can specify the ‘taxInformationNumber` in `MalaysiaAdditionalInfo` with NRIC type, and a valid `MyKad` or NRIC number.
-
For business, you must specify a ‘businessRegistrationNumber` in `MalaysiaAdditionalInfo` with a TIN type and tax identification number.
-
For business resellers, you must specify a ‘businessRegistrationNumber` and `taxInformationNumber` in `MalaysiaAdditionalInfo` with a sales and service tax (SST) type and a valid SST number.
-
For business resellers with service codes, you must specify ‘businessRegistrationNumber`, `taxInformationNumber`, and distinct `serviceTaxCodes` in `MalaysiaAdditionalInfo` with a SST type and valid sales and service tax (SST) number. By using this API operation, Amazon Web Services registers your self-declaration that you’re an authorized business reseller registered with the Royal Malaysia Customs Department (RMCD), and have a valid SST number.
-
Amazon Web Services reserves the right to seek additional information and/or take other actions to support your self-declaration as appropriate.
-
Amazon Web Services is currently registered under the following service tax codes. You must include at least one of the service tax codes in the service tax code strings to declare yourself as an authorized registered business reseller.
Taxable service and service tax codes:
Consultancy - 9907061674
Training or coaching service - 9907071685
IT service - 9907101676
Digital services and electronic medium - 9907121690
Mexico
-
You must provide a Constancia de Situación fiscal (CSF) document in the verificationDetails field.
-
You do not need to provide address and legal name. These will be populated based on your tax registration number.
Nepal
-
The sector valid values are ‘Business` and `Individual`.
^
**Saudi Arabia**
-
For ‘address`, you must specify `addressLine3`.
^
**South Korea**
-
You must specify the ‘certifiedEmailId` and `legalName` in the `TaxRegistrationEntry` object. Use Korean characters for `legalName`.
-
You must specify the ‘businessRepresentativeName`, `itemOfBusiness`, and `lineOfBusiness` in the `southKoreaAdditionalInfo` field of the `additionalTaxInformation` object. Use Korean characters for these fields.
-
You must specify the tax registration certificate document in the ‘taxRegistrationDocuments` field of the `VerificationDetails` object.
-
For the ‘address` object, use Korean characters for `addressLine1`, `addressLine2` `city`, `postalCode`, and `stateOrRegion`.
Spain
-
You must specify the ‘registrationType` in the `spainAdditionalInfo` field of the `additionalTaxInformation` object.
-
If the ‘registrationType` is `Local`, you must specify the tax registration certificate document in the `taxRegistrationDocuments` field of the `VerificationDetails` object.
Turkey
-
You must specify the ‘sector` in the `taxRegistrationEntry` object.
-
If your ‘sector` is `Business`, `Individual`, or `Government`:
-
Specify the ‘taxOffice`. If your `sector` is `Individual`, don’t enter this value.
-
(Optional) Specify the ‘kepEmailId`. If your `sector` is `Individual`, don’t enter this value.
-
Note: In the **Tax Settings** page of the Billing console, ‘Government` appears as **Public institutions**
-
-
If your ‘sector` is `Business` and you’re subject to KDV tax, you must specify your industry in the ‘industries` field.
-
For ‘address`, you must specify `districtOrCounty`.
Ukraine
-
The sector valid values are ‘Business` and `Individual`.
^
Philippines
-
You can optionally specify the ‘isVatRegistered` in the `philippinesAdditionalInfo` field of the `additionalTaxInformation` object to indicate your VAT registration status with the Bureau of Internal Revenue (BIR).
^
Belgium
-
You can optionally specify the ‘peppolId` in the `belgiumAdditionalInfo` field of the `additionalTaxInformation` object.
^
Chile
-
You can optionally specify the ‘documentType` and `businessActivity` in the `chileAdditionalInfo` field of the `additionalTaxInformation` object.
^
France
-
You must specify the ‘sirenNumber` in the `franceAdditionalInfo` field of the `additionalTaxInformation` object.
^
Poland
-
You can optionally specify the ‘taxRegistrationNumberType` in the `polandAdditionalInfo` field of the `additionalTaxInformation` object. Valid values are `EUTaxRegistrationNumber`, `LocalTaxRegistrationNumber`, or `LocalRegistrationNumber`.
^
[1]: console.aws.amazon.com/billing/home#/paymentpreferences/paymentmethods [2]: aws.amazon.com/service-terms/
1942 1943 1944 1945 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1942 def put_tax_registration(params = {}, = {}) req = build_request(:put_tax_registration, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1971 1972 1973 |
# File 'lib/aws-sdk-taxsettings/client.rb', line 1971 def waiter_names [] end |