Class: Aws::TaxSettings::Types::TaxExemptionDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::TaxSettings::Types::TaxExemptionDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-taxsettings/types.rb
Overview
The tax exemption details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#heritage_obtained_details ⇒ Boolean
The indicator if the tax exemption is inherited from the consolidated billing family management account.
-
#heritage_obtained_parent_entity ⇒ String
The consolidated billing family management account the tax exemption inherited from.
-
#heritage_obtained_reason ⇒ String
The reason of the heritage inheritance.
-
#tax_exemptions ⇒ Array<Types::TaxExemption>
Tax exemptions.
Instance Attribute Details
#heritage_obtained_details ⇒ Boolean
The indicator if the tax exemption is inherited from the consolidated billing family management account.
1767 1768 1769 1770 1771 1772 1773 1774 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1767 class TaxExemptionDetails < Struct.new( :tax_exemptions, :heritage_obtained_details, :heritage_obtained_parent_entity, :heritage_obtained_reason) SENSITIVE = [] include Aws::Structure end |
#heritage_obtained_parent_entity ⇒ String
The consolidated billing family management account the tax exemption inherited from.
1767 1768 1769 1770 1771 1772 1773 1774 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1767 class TaxExemptionDetails < Struct.new( :tax_exemptions, :heritage_obtained_details, :heritage_obtained_parent_entity, :heritage_obtained_reason) SENSITIVE = [] include Aws::Structure end |
#heritage_obtained_reason ⇒ String
The reason of the heritage inheritance.
1767 1768 1769 1770 1771 1772 1773 1774 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1767 class TaxExemptionDetails < Struct.new( :tax_exemptions, :heritage_obtained_details, :heritage_obtained_parent_entity, :heritage_obtained_reason) SENSITIVE = [] include Aws::Structure end |
#tax_exemptions ⇒ Array<Types::TaxExemption>
Tax exemptions.
1767 1768 1769 1770 1771 1772 1773 1774 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 1767 class TaxExemptionDetails < Struct.new( :tax_exemptions, :heritage_obtained_details, :heritage_obtained_parent_entity, :heritage_obtained_reason) SENSITIVE = [] include Aws::Structure end |