Class: Aws::TaxSettings::Types::TaxRegistrationWithJurisdiction
- Inherits:
-
Struct
- Object
- Struct
- Aws::TaxSettings::Types::TaxRegistrationWithJurisdiction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-taxsettings/types.rb
Overview
Your TRN information with jurisdiction details. This doesn’t contain the full legal address associated with the TRN information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_tax_information ⇒ Types::AdditionalInfoResponse
Additional tax information associated with your TRN.
-
#certified_email_id ⇒ String
The email address to receive VAT invoices.
-
#jurisdiction ⇒ Types::Jurisdiction
The jurisdiction associated with your TRN information.
-
#legal_name ⇒ String
The legal name associated with your TRN information.
-
#registration_id ⇒ String
Your tax registration unique identifier.
-
#registration_type ⇒ String
The type of your tax registration.
-
#sector ⇒ String
The industry that describes your business.
-
#status ⇒ String
The status of your TRN.
-
#tax_document_metadatas ⇒ Array<Types::TaxDocumentMetadata>
The metadata for your tax document.
Instance Attribute Details
#additional_tax_information ⇒ Types::AdditionalInfoResponse
Additional tax information associated with your TRN.
2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045 class TaxRegistrationWithJurisdiction < Struct.new( :registration_id, :registration_type, :legal_name, :status, :sector, :tax_document_metadatas, :certified_email_id, :additional_tax_information, :jurisdiction) SENSITIVE = [] include Aws::Structure end |
#certified_email_id ⇒ String
The email address to receive VAT invoices.
2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045 class TaxRegistrationWithJurisdiction < Struct.new( :registration_id, :registration_type, :legal_name, :status, :sector, :tax_document_metadatas, :certified_email_id, :additional_tax_information, :jurisdiction) SENSITIVE = [] include Aws::Structure end |
#jurisdiction ⇒ Types::Jurisdiction
The jurisdiction associated with your TRN information.
2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045 class TaxRegistrationWithJurisdiction < Struct.new( :registration_id, :registration_type, :legal_name, :status, :sector, :tax_document_metadatas, :certified_email_id, :additional_tax_information, :jurisdiction) SENSITIVE = [] include Aws::Structure end |
#legal_name ⇒ String
The legal name associated with your TRN information.
2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045 class TaxRegistrationWithJurisdiction < Struct.new( :registration_id, :registration_type, :legal_name, :status, :sector, :tax_document_metadatas, :certified_email_id, :additional_tax_information, :jurisdiction) SENSITIVE = [] include Aws::Structure end |
#registration_id ⇒ String
Your tax registration unique identifier.
2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045 class TaxRegistrationWithJurisdiction < Struct.new( :registration_id, :registration_type, :legal_name, :status, :sector, :tax_document_metadatas, :certified_email_id, :additional_tax_information, :jurisdiction) SENSITIVE = [] include Aws::Structure end |
#registration_type ⇒ String
The type of your tax registration. This can be either ‘VAT` or `GST`.
2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045 class TaxRegistrationWithJurisdiction < Struct.new( :registration_id, :registration_type, :legal_name, :status, :sector, :tax_document_metadatas, :certified_email_id, :additional_tax_information, :jurisdiction) SENSITIVE = [] include Aws::Structure end |
#sector ⇒ String
The industry that describes your business. For business-to-business (B2B) customers, specify Business. For business-to-consumer (B2C) customers, specify Individual. For business-to-government (B2G), specify Government.Note that certain values may not applicable for the request country. Please refer to country specific information in API document.
2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045 class TaxRegistrationWithJurisdiction < Struct.new( :registration_id, :registration_type, :legal_name, :status, :sector, :tax_document_metadatas, :certified_email_id, :additional_tax_information, :jurisdiction) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of your TRN. This can be either ‘Verified`, `Pending`, `Deleted`, or `Rejected`.
2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045 class TaxRegistrationWithJurisdiction < Struct.new( :registration_id, :registration_type, :legal_name, :status, :sector, :tax_document_metadatas, :certified_email_id, :additional_tax_information, :jurisdiction) SENSITIVE = [] include Aws::Structure end |
#tax_document_metadatas ⇒ Array<Types::TaxDocumentMetadata>
The metadata for your tax document.
2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-taxsettings/types.rb', line 2045 class TaxRegistrationWithJurisdiction < Struct.new( :registration_id, :registration_type, :legal_name, :status, :sector, :tax_document_metadatas, :certified_email_id, :additional_tax_information, :jurisdiction) SENSITIVE = [] include Aws::Structure end |